==> haskell-th-reify-many-0.1.6-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-reify-many.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-reify-many
version: 0.1.6
id: th-reify-many-0.1.6-LbiUbxB6WW9AOz1EVvH3xI
key: th-reify-many-0.1.6-LbiUbxB6WW9AOz1EVvH3xI
license: BSD3
maintainer: Michael Sloan <mgsloan at gmail>
stability: Experimental
homepage: http://github.com/mgsloan/th-reify-many
synopsis: Recurseively reify template haskell datatype info
description:
    @th-reify-many@ provides functions for recursively reifying top
    level declarations.  The main intended use case is for enumerating
    the names of datatypes reachable from an initial datatype, and
    passing these names to some function which generates instances.
category: Template Haskell
author: Michael Sloan
exposed: True
exposed-modules:
    Language.Haskell.TH.ReifyMany
    Language.Haskell.TH.ReifyMany.Internal
abi: 398970e363292c0c899e214cc7cf9002
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/th-reify-many-0.1.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/th-reify-many-0.1.6
data-dir: /usr/share/arm-linux-ghc-8.0.1/th-reify-many-0.1.6
hs-libraries: HSth-reify-many-0.1.6-LbiUbxB6WW9AOz1EVvH3xI
depends:
    base-4.9.0.0 containers-0.5.7.1 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    safe-0.3.13-Fz8SHW48R8E7ldyMo2658O template-haskell-2.11.0.0
    th-expand-syns-0.4.2.0-8otRGL0EjKzK6m0QRhxIJn
haddock-interfaces: /usr/share/doc/haskell-th-reify-many/html/th-reify-many.haddock
haddock-html: /usr/share/doc/haskell-th-reify-many/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-reify-many-0.1.6-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-reify-many.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-reify-many
version: 0.1.6
id: th-reify-many-0.1.6-HIcyW4oKoS86IBXOWG3PUU
key: th-reify-many-0.1.6-HIcyW4oKoS86IBXOWG3PUU
license: BSD3
maintainer: Michael Sloan <mgsloan at gmail>
stability: Experimental
homepage: http://github.com/mgsloan/th-reify-many
synopsis: Recurseively reify template haskell datatype info
description:
    @th-reify-many@ provides functions for recursively reifying top
    level declarations.  The main intended use case is for enumerating
    the names of datatypes reachable from an initial datatype, and
    passing these names to some function which generates instances.
category: Template Haskell
author: Michael Sloan
exposed: True
exposed-modules:
    Language.Haskell.TH.ReifyMany
    Language.Haskell.TH.ReifyMany.Internal
abi: a0c6eebc35915539b9b2e1a046f12f0a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/th-reify-many-0.1.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/th-reify-many-0.1.6
data-dir: /usr/share/arm-linux-ghc-8.0.1/th-reify-many-0.1.6
hs-libraries: HSth-reify-many-0.1.6-HIcyW4oKoS86IBXOWG3PUU
depends:
    base-4.9.0.0 containers-0.5.7.1 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    safe-0.3.14-ALdwhNEer7fKnF5VYCbXfH template-haskell-2.11.0.0
    th-expand-syns-0.4.2.0-8otRGL0EjKzK6m0QRhxIJn
haddock-interfaces: /usr/share/doc/haskell-th-reify-many/html/th-reify-many.haddock
haddock-html: /usr/share/doc/haskell-th-reify-many/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
